<?php

/**
 * BrMap extension class.
 * Map of Brazil interactive
 * 
 * @version 1.0 
 * @package    Extension
 * @author     Fernando Rosa <nando.megaman@gmail.com>
 * @copyright  (c) 2011 Fernando Rosa
 * @uses Julio API http://code.google.com/p/julio/
 */

/**
 * @example 
 * <?php
 * $states = array('SC','RS');
 * $brMap = Yii::createComponent(array(
 * 'class'=>'application.extensions.brmap.BrMap',
 * 'width'=>580,
 * 'height'=>600,
 * 'callbackFunctionName' => 'renderTest',
 * 'borderColor' => '0x888888',
 * 'background' => '0xDDDDDD'
 * ));
 * $brMap->changeColorStates('0x777777',  array_values($states));
 * $brMap->build();        
 * ?>
 * 
 * <script type="text/javascript">
 *  function renderTest(uf){
 *      alert(uf);     
 *  }
 * </script>     
 */

class BrMap extends CComponent {

    public $width = 580;
    public $height = 600;    
    public $borderColor = '0xBBBBBB';
    public $background = '0xDDDDDD';
    public $opacity = 40;    
    public $interactive = true;
    public $differenceRollover = 25;
    public $zoomState;
    public $callbackType = 'JS';
    public $callbackFunctionName;
    public $messageErrorFlash = 'Error opening flash file.';
    public $urlGetFlashPlayer = 'http://www.adobe.com/go/getflashplayer';
    private $_updateDivID = 'brmap-div';
    private $_functions;
    private $_flashVars=array(
        'borderColor' => 'contorno',
        'background' => 'cor',
        'opacity' => 'opacidade',
        'interactive' => 'interativo',
        'differenceRollover' => 'diferenca_rollover',
        'zoomState'=>'zoom_uf',
        'callbackType'=>'funcao_tipo',
        'callbackFunctionName'=>'funcao'   
    );
    
    public function build(){
        $this->_registerScript();
        $this->_render();                
    }
    
    private function _render(){
        echo CHtml::tag('div', array('id'=>$this->_updateDivID), 
             CHtml::tag('span', array(), $this->messageErrorFlash).
             CHtml::tag('br').
             CHtml::link(CHtml::image(Yii::app()->getAssetManager()->publish(dirname(__FILE__)).'/julio/src/get.gif', 
             'Get Flash Player'), $this->urlGetFlashPlayer, array('title'=>'Get Flash Player')));
    }
    
    private function _registerScript(){
        $functionsInit = (isset($this->_functions)) ? str_replace(';', '; ', $this->_functions) : '';        
        $flashVarsConfig = $this->_loadFlashVars();
        $cScript = Yii::app()->clientScript;
        $cScript->registerScriptFile(Yii::app()->assetManager->publish(dirname(__FILE__)).'/julio/js/swfobject.js');        
        $cScript->registerCoreScript('jquery');        
        $cScript->registerScript(__CLASS__.'brmap_1',
            'var flashvars = {};
             var params = {};
             params.allowscriptaccess = "always";
	     var attributes = {};
	     attributes.id = "julio";
	     attributes.name = "julio";
             '.$flashVarsConfig.'
	     swfobject.embedSWF("'.Yii::app()->getAssetManager()->publish(dirname(__FILE__)).
             '/julio/flash/julio.swf", "'.$this->_updateDivID.'", "'.$this->width.'", "'.$this->height.'", 
             "8.0.0", false, flashvars, params, attributes);                
        ');        
        $cScript->registerScript(__CLASS__.'brmap_2','
            function getJulio(nome) {
                if(!nome)
                    nome = "julio"                    
                var isIE = navigator.appName.indexOf("Microsoft") != -1;
                return (isIE) ? window[nome] : document[nome];
            }
            function inicializaJulio(){ '.$functionsInit.' }',  CClientScript::POS_BEGIN
        );
    }
    
    private function _loadFlashVars(){
        foreach ($this->_flashVars as $property => $flashvar):
            if(isset($this->{$property})):
                $value = (is_string($this->{$property})) ? "'".$this->{$property}."'" : $this->{$property};
                $flashVars .= "flashvars.".$flashvar." = ".$value.";";
            endif;            
        endforeach;
        return str_replace(';', '; ', $flashVars);
    }
    
    public function changeColor($color) {
        $this->_functions .= "getJulio().mudaCorBr('{$color}');";
    }
    
    public function changeColorState($color, $state) {
        $this->_functions .= "getJulio().mudaCor('{$color}','{$state}');";
    }
    
    public function changeColorRegion($color,$region) {
        $this->_functions .= "getJulio().mudaCorRegiao('{$color}','{$region}');";
    }
    
    public function changeColorStates($color,$states) {
        $this->_functions .= "getJulio().mudaCorEmLote('{$color}',".CJavaScript::encode($states).");";
    }
    
    public function changeOpacity($opacity) {
        $this->_functions .= "getJulio().mudaOpacidadeBr({$opacity});";
    }
    
    public function changeOpacityState($opacity,$state) {
        $this->_functions .= "getJulio().mudaOpacidade({$opacity},'{$state}');";
    }
    
    public function changeOpacityRegion($opacity,$region) {
        $this->_functions .= "getJulio().mudaOpacidadeRegiao({$opacity},'{$region}');";
    }
    
    public function changeOpacityStates($opacity,$states) {
        $this->_functions .= "getJulio().mudaOpacidadeEmLote({$opacity},".CJavaScript::encode($states).");";
    }
    
    public function changeDifferenceRollover($difference){
        $this->_functions .= "getJulio().defineDiferencaRollover({$difference});";        
    }
    
    public function highLightState($state){
        $this->_functions .= "getJulio().destaca('{$state}');";        
    }
    
    public function assignValueState($state,$value){
        $this->_functions .= "getJulio().atribuiValor('{$state}','{$value}');";        
    }
    
    public function assignValuesStates($states,$values){
        $this->_functions .= "getJulio().atribuiValor(".CJavaScript::encode($states).",".CJavaScript::encode($values).");";                
    }

    public function defineCallbackFunctionName($type,$functionName){
        $this->_functions .= "getJulio().defineFuncao('{$type}','{$functionName}');";        
    }
    
    public function insertPoint($x,$y,$size,$color,$opacity,$name){
        $this->_functions .= "getJulio().inserePonto({$x},{$y},{$size}, '{$color}', {$opacity}, '{$name}');";
    }
    
}

?>